<?php  
// Fonction pour générer un mot de passe sécurisé
function generatePassword($length = 12, $uppercase = true, $numbers = true, $symbols = true) {
  // Définition des jeux de caractères disponibles pour la génération du mot de passe
  $lowercaseChars = 'abcdefghijklmnopqrstuvwxyz'; // Lettres minuscules
  $uppercaseChars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'; // Lettres majuscules
  $numberChars = '0123456789'; // Chiffres
  $symbolChars = '!@#$%^&*()-_=+[]{}<>?,.'; // Symboles

  // Commencer avec les lettres minuscules obligatoires
  $allChars = $lowercaseChars;
  
  // Ajouter les caractères supplémentaires en fonction des options choisies
  if ($uppercase) $allChars .= $uppercaseChars; // Ajouter les majuscules si sélectionné
  if ($numbers) $allChars .= $numberChars;      // Ajouter les chiffres si sélectionné
  if ($symbols) $allChars .= $symbolChars;      // Ajouter les symboles si sélectionné

  // Initialisation du mot de passe vide
  $password = '';
  $max = strlen($allChars) - 1; // Définir l'indice maximal pour sélectionner un caractère aléatoire

  // Génération du mot de passe caractère par caractère
  for ($i = 0; $i < $length; $i++) {
    // Utilisation de random_int pour une meilleure sécurité cryptographique
    // random_int génère un nombre aléatoire cryptographiquement sécurisé
    $password .= $allChars[random_int(0, $max)];
  }

  return $password; // Retourner le mot de passe généré
}

// Initialisation de la variable pour afficher le mot de passe généré
$generatedPassword = '';

// Vérifie si le formulaire a été soumis via la méthode POST
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
  // Récupère et sécurise les options envoyées via le formulaire
  $length = max(4, intval($_POST['length']));       // Longueur minimale de 4 caractères
  $uppercase = isset($_POST['uppercase']);          // Vérifie si l'option majuscules est cochée
  $numbers = isset($_POST['numbers']);              // Vérifie si l'option chiffres est cochée
  $symbols = isset($_POST['symbols']);              // Vérifie si l'option symboles est cochée

  // Génère le mot de passe avec les options choisies par l'utilisateur
  $generatedPassword = generatePassword($length, $uppercase, $numbers, $symbols);
}
?>

<!DOCTYPE html>
<html lang="fr">
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>Générateur de mot de passe</title>
  <style>
    /* Style de base pour une présentation claire et moderne */
    body { font-family: Arial, sans-serif; padding: 20px; background: #f4f4f4; }
    .box { background: white; padding: 20px; border-radius: 8px; max-width: 500px; margin: auto; box-shadow: 0 0 10px #ccc; }
    h2 { text-align: center; }
    form { display: flex; flex-direction: column; gap: 12px; }
    input[type="number"], button { padding: 10px; border-radius: 5px; border: 1px solid #ccc; font-size: 16px; }
    label { display: flex; align-items: center; gap: 8px; }
    button { background-color: #2d89ef; color: white; border: none; cursor: pointer; }
    button:hover { background-color: #1b5eaa; }
    .result { margin-top: 20px; font-weight: bold; background: #eef; padding: 10px; border-radius: 5px; text-align: center; }

    a {
    text-decoration: none;
    color: #2d89ef; /* Bleu moderne */
    font-weight: bold;
    transition: color 0.3s ease, border-bottom 0.3s ease;
    border-bottom: 2px solid transparent;
    }

    a:hover {
        color: #1b5eaa;
        border-bottom: 2px solid #1b5eaa;
    }
  </style>
</head>
<body>
<div class="box">
  <h2>Générateur de mot de passe</h2>

  <!-- Formulaire permettant à l'utilisateur de sélectionner les options de génération du mot de passe -->
  <form method="POST">
    <label>Longueur : <input type="number" name="length" value="12" min="4" max="64"></label> <!-- Champ pour la longueur -->
    <label><input type="checkbox" name="uppercase" checked> Lettres majuscules</label> <!-- Option majuscules -->
    <label><input type="checkbox" name="numbers" checked> Chiffres</label> <!-- Option chiffres -->
    <label><input type="checkbox" name="symbols" checked> Symboles</label> <!-- Option symboles -->
    <button type="submit">Générer</button> <!-- Bouton pour soumettre le formulaire -->
  </form>
  <br>
  <a href="https://www.xeocoder.com" target="_blank">Propulsé par xeocoder.com</a>

  <!-- Affichage du mot de passe généré si disponible -->
  <?php if ($generatedPassword): ?>
    <div class="result">
      Votre mot de passe : <br>
      <code><?= htmlspecialchars($generatedPassword) ?></code> <!-- Protection XSS pour afficher le mot de passe -->
    </div>
  <?php endif; ?>
</div>
</body>
</html>
